@@ -1,6 +1,6 @@
 from muid.mining import mine, create
 from muid.corpus import to_readable_hex, from_readable_hex, pretty, search
-from muid.validation import validate, animal
+from muid.validation import validate, animal, difficulty
 from muid.crypto import bhash, shash
 
 
