@@ -2,7 +2,7 @@ from muid.corpus import search
 from muid.crypto import bhash
 
 def difficulty(key):
-    return len(animal(key).replace(' ',''))
+    return len((animal(key) or '').replace(' ',''))
 
 def animal(key):
     bkey = key if isinstance(key,bytes) else key.encode('ascii')
